
# THIS FILE IS GENERATED FROM SCIKIT-NANO SETUP.PY
short_version = '0.2.22'
version = '0.2.22'
full_version = '0.2.22'
git_revision = 'a67d2c2d5bbaea045399dde4a473d92d30f0acb6'
release = True

if not release:
    version = full_version
